<?php
/**
* @Copyright Copyright (C) 2010 www.profinvent.com. All rights reserved.
* @website http://www.profinvent.com
* @license GNU/GPL http://www.gnu.org/copyleft/gpl.html
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 2 of the License, or
* any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
**/

defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

class CoursemanModelArchive extends JModel
{
    var $_data = null;

    var $_cats = null;

    var $_total = null;

    var $_pagination = null;

    var $_id = null;

    function __construct()
    {
        parent::__construct();

        global $mainframe, $option;

        $limit = $mainframe->getUserStateFromRequest($option . '.limit', 'limit', $mainframe->
            getCfg('list_limit'), 'int');
        $limitstart = $mainframe->getUserStateFromRequest($option . '.limitstart',
            'limitstart', 0, 'int');

        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);

        $array = JRequest::getVar('cid', 0, '', 'array');
        $this->setId((int)$array[0]);

    }

    function setId($id)
    {

        $this->_id = $id;
        $this->_data = null;
        $this->_cats = null;
    }

    function getData()
    {

        if (empty($this->_data))
        {
            $query = $this->_buildQuery();
            $this->_data = $this->_getList($query, $this->getState('limitstart'), $this->
                getState('limit'));

            $k = 0;
            $count = count($this->_data);
            for ($i = 0; $i < $count; $i++)
            {
                $course = &$this->_data[$i];
                $course->categories = $this->getCategories($course->id);
                $k = 1 - $k;
            }

        }

        return $this->_data;
    }

    function getTotal()
    {

        if (empty($this->_total))
        {
            $query = $this->_buildQuery();
            $this->_total = $this->_getListCount($query);
        }

        return $this->_total;
    }

    function getPagination()
    {

        if (empty($this->_pagination))
        {
            jimport('joomla.html.pagination');
            $this->_pagination = new JPagination($this->getTotal(), $this->getState('limitstart'),
                $this->getState('limit'));
        }

        return $this->_pagination;
    }

    function _buildQuery()
    {

        $where = $this->_buildContentWhere();
        $orderby = $this->_buildContentOrderBy();

        $query = 'SELECT DISTINCT rel.courseid, i.*, u.name AS editor' .
            ' FROM #__courseman_courses AS i' .
            ' LEFT JOIN #__courseman_cats_course_relations AS rel ON rel.courseid = i.id' .
            ' LEFT JOIN #__users AS u ON u.id = i.checked_out' . $where . $orderby;

        return $query;
    }

    function _buildContentOrderBy()
    {
        global $mainframe, $option;

        $filter_order = $mainframe->getUserStateFromRequest($option .
            '.archive.filter_order', 'filter_order', 'i.ordering', 'cmd');
        $filter_order_Dir = $mainframe->getUserStateFromRequest($option .
            '.archive.filter_order_Dir', 'filter_order_Dir', '', 'word');

        $orderby = ' ORDER BY ' . $filter_order . ' ' . $filter_order_Dir .
            ', i.ordering';

        return $orderby;
    }

    function _buildContentWhere()
    {
        global $mainframe, $option;

        $search = $mainframe->getUserStateFromRequest($option . '.archive.search',
            'search', '', 'string');
        $search = $this->_db->getEscaped(trim(JString::strtolower($search)));

        $where = array();

        $where[] = ' i.state = -1';

        if ($search)
        {
            $where[] = ' LOWER(i.title) LIKE ' . $this->_db->Quote('%' . $this->_db->
                getEscaped($search, true) . '%', false);
        }

        $where = (count($where) ? ' WHERE ' . implode(' AND ', $where) : '');

        return $where;
    }

    function delete($cid)
    {
        if (count($cid))
        {
            $cids = implode(',', $cid);
            $query = 'DELETE FROM #__courseman_courses' . ' WHERE id IN (' . $cids . ')';

            $this->_db->setQuery($query);

            if (!$this->_db->query())
            {
                $this->setError($this->_db->getErrorMsg());
                return false;
            }

            $query = 'DELETE FROM #__courseman_tags_course_relations' . ' WHERE courseid IN (' . $cids .
                ')';
            $this->_db->setQuery($query);

            if (!$this->_db->query())
            {
                $this->setError($this->_db->getErrorMsg());
                return false;
            }

            $query = 'DELETE FROM #__courseman_cats_course_relations' . ' WHERE courseid IN (' . $cids .
                ')';
            $this->_db->setQuery($query);

            if (!$this->_db->query())
            {
                $this->setError($this->_db->getErrorMsg());
                return false;
            }

            $query = 'DELETE FROM #__courseman_files_course_relations' . ' WHERE courseid IN (' . $cids .
                ')';
            $this->_db->setQuery($query);

            if (!$this->_db->query())
            {
                $this->setError($this->_db->getErrorMsg());
                return false;
            }

            return true;
        }

        return false;
    }

    function getCategories($id)
    {
        $query = 'SELECT DISTINCT c.id, c.title' . ' FROM #__courseman_categories AS c' .
            ' LEFT JOIN #__courseman_cats_course_relations AS rel ON rel.catid = c.id' .
            ' WHERE rel.courseid = ' . (int)$id;

        $this->_db->setQuery($query);

        $this->_cats = $this->_db->loadObjectList();

        return $this->_cats;
    }

    function unarchive($cid = array())
    {
        $user = &JFactory::getUser();
        $userid = (int)$user->get('id');

        if (count($cid))
        {
            $cids = implode(',', $cid);

            $query = 'UPDATE #__courseman_courses' . ' SET state = 0' . ' WHERE id IN (' . $cids .
                ')' . ' AND ( checked_out = 0 OR ( checked_out = ' . $userid . ' ) )';
            $this->_db->setQuery($query);
            if (!$this->_db->query())
            {
                $this->setError($this->_db->getErrorMsg());
                return false;
            }

            return true;
        }

        return false;
    }
}

?>